@@ -235,7 +235,7 @@ queries until after they have been run.
 =cut
 
 package Test::DBIC::ExpectedQueries;
-$Test::DBIC::ExpectedQueries::VERSION = '1.005';
+$Test::DBIC::ExpectedQueries::VERSION = '1.006';
 use Moo;
 BEGIN {extends "Attribute::Exporter"};
 
@@ -423,7 +423,7 @@ sub check_table_operation_counts {
 
     if(scalar keys %$table_test_result) {
         my $message = "";
-        for my $table (sort keys $table_test_result) {
+        for my $table (sort keys %{$table_test_result}) {
             $message .= "* Table: $table\n";
             $message .= join("\n", @{$table_test_result->{$table}});
             $message .= "\nActually executed SQL queries on table '$table':\n";
@@ -501,6 +501,17 @@ __END__
 Johan Lindstrom, C<< <johanl [AT] cpan.org> >>
 
 
+=head2 Contributors
+
+Many thanks to:
+
+=over 4
+
+=item Syohei YOSHIDA (syohex)
+
+=back
+
+
 =head2 Source code
 
 L<https://github.com/jplindstrom/p5-Test-DBIC-ExpectedQueries>
